@@ -1,5 +1,5 @@
 package DBIx::Class::Wrapper::Factory;
-$DBIx::Class::Wrapper::Factory::VERSION = '0.006';
+$DBIx::Class::Wrapper::Factory::VERSION = '0.007';
 use Moose;
 extends qw/DBIx::Class::Wrapper::FactoryBase/;
 
@@ -134,6 +134,18 @@ sub first{
   return $original ? $self->wrap($original) : undef;
 }
 
+=head2 single
+
+Equivalent to DBIx::Class::ResultSet::single. It's a bit more efficient than C<first()>.
+
+=cut
+
+sub single {
+  my ($self) = @_;
+  my $original = $self->dbic_rs->single();
+  return $original ? $self->wrap($original) : undef;
+}
+
 =head2 find_or_create
 
 Wraps around the original DBIC find_or_create method.
